Learn R Programming

lmom (version 2.8)

cdfglo: Generalized logistic distribution

Description

Distribution function and quantile function of the generalized logistic distribution.

Usage

cdfglo(x, para = c(0, 1, 0))
quaglo(f, para = c(0, 1, 0))

Arguments

x

Vector of quantiles.

f

Vector of probabilities.

para

Numeric vector containing the parameters of the distribution, in the order \(\xi, \alpha, k\) (location, scale, shape).

Value

cdfglo gives the distribution function; quaglo gives the quantile function.

Details

The generalized logistic distribution with location parameter \(\xi\), scale parameter \(\alpha\) and shape parameter \(k\) has distribution function $$F(x)=1/\lbrace 1+\exp(-y)\rbrace$$ where $$y=-k^{-1}\log\lbrace1-k(x-\xi)/\alpha\rbrace,$$ with \(x\) bounded by \(\xi+\alpha/k\) from below if \(k<0\) and from above if \(k>0\), and quantile function $$x(F)=\xi+{\alpha\over k}\biggl\lbrace1-\biggl({1-F \over F}\biggr)^k\biggr\rbrace.$$

The logistic distribution is the special case \(k=0\).

See Also

cdfkap for the kappa distribution, which generalizes the generalized logistic distribution.

Examples

Run this code
# NOT RUN {
# Random sample from the generalized logistic distribution
# with parameters xi=0, alpha=1, k=-0.5.
quaglo(runif(100), c(0,1,-0.5))
# }

Run the code above in your browser using DataLab