Learn R Programming

lmom (version 2.8)

cdfgum: Gumbel (extreme-value type I) distribution

Description

Distribution function and quantile function of the Gumbel distribution.

Usage

cdfgum(x, para = c(0, 1))
quagum(f, para = c(0, 1))

Arguments

x

Vector of quantiles.

f

Vector of probabilities.

para

Numeric vector containing the parameters of the distribution, in the order \(\xi, \alpha\) (location, scale).

Value

cdfgum gives the distribution function; quagum gives the quantile function.

Details

The Gumbel distribution with location parameter \(\xi\) and scale parameter \(\alpha\) has distribution function $$F(x)=\exp[-\exp\lbrace-(x-\xi)/\alpha\rbrace]$$ and quantile function $$x(F)=\xi-\alpha\log(-\log F).$$

See Also

cdfgev for the generalized extreme-value distribution, which generalizes the Gumbel distribution.

Examples

Run this code
# NOT RUN {
# Random sample from the Gumbel distribution with parameters xi=0, alpha=3.
quagum(runif(100), c(0,3))
# }

Run the code above in your browser using DataLab