Learn R Programming

lmom (version 2.8)

cdfkap: Kappa distribution

Description

Distribution function and quantile function of the kappa distribution.

Usage

cdfkap(x, para = c(0, 1, 0, 0))
quakap(f, para = c(0, 1, 0, 0))

Arguments

x

Vector of quantiles.

f

Vector of probabilities.

para

Numeric vector containing the parameters of the distribution, in the order \(\xi, \alpha, k, h\) (location, scale, shape, shape).

Value

cdfkap gives the distribution function; quakap gives the quantile function.

Details

The kappa distribution with location parameter \(\xi\), scale parameter \(\alpha\) and shape parameters \(k\) and \(h\) has quantile function $$x(F)=\xi+{\alpha\over k}\biggl\lbrace1-\biggl({1-F^h \over h}\biggr)^k\biggr\rbrace.$$

Its special cases include the generalized logistic (\(h=-1\)), generalized extreme-value (\(h=0\)), generalized Pareto (\(h=1\)), logistic (\(k=0\), \(h=-1\)), Gumbel (\(k=0\), \(h=0\)), exponential (\(k=0\), \(h=1\)), and uniform (\(k=1\), \(h=1\)) distributions.

References

Hosking, J. R. M. (1994). The four-parameter kappa distribution. IBM Journal of Research and Development, 38, 251-258.

Hosking, J. R. M., and Wallis, J. R. (1997). Regional frequency analysis: an approach based on L-moments, Cambridge University Press, Appendix A.10.

See Also

cdfglo for the generalized logistic distribution, cdfgev for the generalized extreme-value distribution, cdfgpa for the generalized Pareto distribution, cdfgum for the Gumbel distribution, cdfexp for the exponential distribution.

Examples

Run this code
# NOT RUN {
# Random sample from the kappa distribution
# with parameters xi=0, alpha=1, k=-0.5, h=0.25.
quakap(runif(100), c(0,1,-0.5,0.25))
# }

Run the code above in your browser using DataLab