Learn R Programming

lmom (version 2.8)

cdfnor: Normal distribution

Description

Distribution function and quantile function of the normal distribution.

Usage

cdfnor(x, para = c(0, 1))
quanor(f, para = c(0, 1))

Arguments

x

Vector of quantiles.

f

Vector of probabilities.

para

Numeric vector containing the parameters of the distribution, in the order \(\mu, \sigma\) (location, scale).

Value

cdfnor gives the distribution function; quanor gives the quantile function.

Details

The normal distribution with location parameter \(\mu\) and scale parameter \(\sigma\) has probability density function $$f(x)={1\over \sigma\sqrt{2\pi}} \exp\lbrace-(x-\mu)^2/(2 \sigma^2)\rbrace.$$

See Also

pnorm for the standard R version of the normal distribution.

cdfgno for the generalized normal distribution, which generalizes the normal distribution.

Examples

Run this code
# NOT RUN {
# Random sample from the normal distribution
# with mean 0 and standard deviation 3.
quanor(runif(100), c(0,3))
# }

Run the code above in your browser using DataLab