Learn R Programming

lmom (version 2.8)

cdfwei: Weibull distribution

Description

Distribution function and quantile function of the Weibull distribution.

Usage

cdfwei(x, para = c(0, 1, 1))
quawei(f, para = c(0, 1, 1))

Arguments

x

Vector of quantiles.

f

Vector of probabilities.

para

Numeric vector containing the parameters of the distribution, in the order \(\zeta, \beta, \delta\) (location, scale, shape).

Value

cdfwei gives the distribution function; quawei gives the quantile function.

Details

The Weibull distribution with location parameter \(\zeta\), scale parameter \(\beta\) and shape parameter \(\delta\) has distribution function $$F(x)=1-\exp[-\lbrace(x-\zeta)/\beta\rbrace^\delta]$$ for \(x>\zeta\).

See Also

cdfgev for the generalized extreme-value distribution, of which the Weibull (reflected through the origin) is a special case.

Examples

Run this code
# NOT RUN {
# Random sample from a 2-parameter Weibull distribution
# with scale parameter 2 and shape parameter 1.5.
quawei(runif(100), c(0,2,1.5))

# Illustrate the relation between Weibull and GEV distributions.
# weifit() fits a Weibull distribution to data and returns
#   quantiles of the fitted distribution
# gevfit() fits a Weibull distribution as a "reverse GEV",
#   i.e. fits a GEV distribution to the negated data,
#   then computes negated quantiles
weifit <- function(qval, x) quawei(qval, pelwei(samlmu(x)))
gevfit <- function(qval, x) -quagev(1-qval, pelgev(samlmu(-x)))
# Compare on Ozone data
data(airquality)
weifit(c(0.2,0.5,0.8), airquality$Ozone)
gevfit(c(0.2,0.5,0.8), airquality$Ozone)
# }

Run the code above in your browser using DataLab