Computes the parameters of a probability distribution as a function of the \(L\)-moments. The following distributions are recognized:
pelexp |
exponential | |
pelgam |
gamma | |
pelgev |
generalized extreme-value | |
pelglo |
generalized logistic | |
pelgpa |
generalized Pareto | |
pelgno |
generalized normal | |
pelgum |
Gumbel (extreme-value type I) | |
pelkap |
kappa | |
pelln3 |
three-parameter lognormal | |
pelnor |
normal | |
pelpe3 |
Pearson type III | |
pelwak |
Wakeby | |
pelwei |
Weibull |
pelexp(lmom)
pelgam(lmom)
pelgev(lmom)
pelglo(lmom)
pelgno(lmom)
pelgpa(lmom, bound = NULL)
pelgum(lmom)
pelkap(lmom)
pelln3(lmom, bound = NULL)
pelnor(lmom)
pelpe3(lmom)
pelwak(lmom, bound = NULL, verbose = FALSE)
pelwei(lmom, bound = NULL)Numeric vector containing the \(L\)-moments of the distribution or of a data sample.
Lower bound of the distribution. If NULL (the default),
the lower bound will be estimated along with the other parameters.
Logical: whether to print a message when not all parameters of the distribution can be computed.
A numeric vector containing the parameters of the distribution.
Numerical methods and accuracy are as described in
Hosking (1996, pp. 10--11).
Exception:
if pelwak is unable to fit a Wakeby distribution using all 5 \(L\)-moments,
it instead fits a generalized Pareto distribution to the first 3 \(L\)-moments.
(The corresponding routine in the LMOMENTS Fortran package
would attempt to fit a Wakeby distribution with lower bound zero.)
Hosking, J. R. M. (1996). Fortran routines for use with the method of \(L\)-moments, Version 3. Research Report RC20525, IBM Research Division, Yorktown Heights, N.Y.
pelp for parameter estimation of a general distribution
specified by its cumulative distribution function or quantile function.
lmrexp, etc., to compute the \(L\)-moments
of a distribution given its parameters.
For individual distributions, see their cumulative distribution functions:
cdfexp |
exponential | |
cdfgam |
gamma | |
cdfgev |
generalized extreme-value | |
cdfglo |
generalized logistic | |
cdfgpa |
generalized Pareto | |
cdfgno |
generalized normal | |
cdfgum |
Gumbel (extreme-value type I) | |
cdfkap |
kappa | |
cdfln3 |
three-parameter lognormal | |
cdfnor |
normal | |
cdfpe3 |
Pearson type III | |
cdfwak |
Wakeby | |
cdfwei |
Weibull |
# NOT RUN {
# Sample L-moments of Ozone from the airquality data
data(airquality)
lmom <- samlmu(airquality$Ozone)
# Fit a GEV distribution
pelgev(lmom)
# }
Run the code above in your browser using DataLab