pelexp exponential
pelgam gamma
pelgev generalized extreme-value
pelglo generalized logistic
pelgpa generalized Pareto
pelgno generalized normal
pelgum Gumbel (extreme-value type I)
pelkap kappa
pelln3 three-parameter lognormal
pelnor normal
pelpe3 Pearson type III
pelwak Wakeby
pelwei Weibull
}pelexp(lmom)
pelgam(lmom)
pelgev(lmom)
pelglo(lmom)
pelgno(lmom)
pelgpa(lmom, bound = NULL)
pelgum(lmom)
pelkap(lmom)
pelln3(lmom, bound = NULL)
pelnor(lmom)
pelpe3(lmom)
pelwak(lmom, bound = NULL, verbose = FALSE)
pelwei(lmom, bound = NULL)NULL (the default),
the lower bound will be estimated along with the other parameters.pelp for parameter estimation of a general distribution
specified by its cumulative distribution function or quantile function.
lmrexp, etc., to compute the $L$-moments
of a distribution given its parameters.
For individual distributions, see their cumulative distribution functions:
cdfexp exponential
cdfgam gamma
cdfgev generalized extreme-value
cdfglo generalized logistic
cdfgpa generalized Pareto
cdfgno generalized normal
cdfgum Gumbel (extreme-value type I)
cdfkap kappa
cdfln3 three-parameter lognormal
cdfnor normal
cdfpe3 Pearson type III
cdfwak Wakeby
cdfwei Weibull
}# Sample L-moments of Ozone from the airquality data
data(airquality)
lmom <- samlmu(airquality$Ozone)
# Fit a GEV distribution
pelgev(lmom)Run the code above in your browser using DataLab